@@ -21,4 +21,14 @@ impl KubeadmConfigTemplate {
         };
         Self::new(name, spec)
     }
+
+    pub fn namespace(self, namespace: &str) -> Self {
+        Self {
+            metadata: kube::core::ObjectMeta {
+                namespace: Some(namespace.to_string()),
+                ..self.metadata
+            },
+            ..self
+        }
+    }
 }
