@@ -1,8 +1,5 @@
 use std::fmt;
 
-// use k8s_openapi::api::core::v1::ObjectReference;
-use kube::Resource;
-
 use super::*;
 
 impl Cluster {
@@ -49,9 +46,7 @@ impl Cluster {
     // }
 
     pub fn set_control_plane(self, control_plane: &ControlPlane) -> Self {
-        let control_plane_ref = match control_plane {
-            ControlPlane::Kubeadm(kubeadm) => kubeadm.object_ref(&()),
-        };
+        let control_plane_ref = control_plane.object_ref();
         Self {
             spec: ClusterSpec {
                 control_plane_ref: Some(control_plane_ref),
@@ -62,9 +57,7 @@ impl Cluster {
     }
 
     pub fn set_infrastructure(self, infrastructure: &Infrastructure) -> Self {
-        let infrastructure_ref = match infrastructure {
-            Infrastructure::Aws(awscluster) => awscluster.object_ref(&()),
-        };
+        let infrastructure_ref = infrastructure.object_ref();
         Self {
             spec: ClusterSpec {
                 infrastructure_ref: Some(infrastructure_ref),
