@@ -73,4 +73,14 @@ impl KubeadmControlPlane {
             ..self
         }
     }
+
+    pub fn namespace(self, namespace: &str) -> Self {
+        Self {
+            metadata: kube::core::ObjectMeta {
+                namespace: Some(namespace.to_string()),
+                ..self.metadata
+            },
+            ..self
+        }
+    }
 }
